// A basic OpenGL program displaying a 2D house shape
// Burkhard Wuensche, 22 Feb 2002

#include <windows.h>
#include <gl/gl.h>
#include <gl/glu.h>
#include <gl/glut.h>
#include <stdio.h>

#include "ParametricCurve.h"

const int windowWidth=300;
const int windowHeight=300;

CParametricCircle circle(220, 100, 50);
CParametricEllipsoid ellipsoid(100, 40, 90, 30);
CLogarithmicSpiral spiral(80, 220, 6.0, 0.14, 3);
CRoseCurve rose(230, 230, 60, 4);

void display(void)
{
	// clear all pixels in frame buffer
	glClear(GL_COLOR_BUFFER_BIT);
	glLineWidth(2.0f);
	glColor3f(0.0, 0.0, 0.0);	// black
	circle.draw();
	glColor3f(1.0, 0.0, 0.0);	// red
	ellipsoid.draw();
	glColor3f(0.0, 1.0, 0.0);	// green
	spiral.draw();
	glColor3f(0.0, 0.0, 1.0);	// blue
	rose.draw();
	// start processing buffered OpenGL routines 
	glFlush ();
}

void init(void) 
{
	// select clearing color (for glClear)
	glClearColor (1.0, 1.0, 1.0, 0.0);	// RGB-value for white

	// initialize view (simple orthographic projection)
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	gluOrtho2D(0,windowWidth,0,windowHeight);
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
}


// create a single buffered colour window
int main(int argc, char** argv)
{
	glutInit(&argc, argv);		
	glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
	glutInitWindowSize(windowWidth, windowHeight); 
	glutInitWindowPosition(100, 100);
	glutCreateWindow("Parametric curves");
	init ();						// initialise view
	glutDisplayFunc(display);		// draw scene
	glutMainLoop();
	return 0;
}
